PublicApiDiff

Struct PublicApiDiff 

pub struct PublicApiDiff {
    pub removed: Vec<PublicItem>,
    pub changed: Vec<ChangedPublicItem>,
    pub added: Vec<PublicItem>,
}
The return value of Self::between. To quickly get a sense of what it contains, you can pretty-print it:

println!("{:#?}", public_api_diff);

Fields

removed: Vec<PublicItem>

Items that have been removed from the public API. A MAJOR change, in semver terminology. Sorted.

changed: Vec<ChangedPublicItem>

Items in the public API that has been changed. Generally a MAJOR change, but exceptions exist. For example, if the return value of a method is changed from ExplicitType to Self and Self is the same as ExplicitType.

added: Vec<PublicItem>

Items that have been added to public API. A MINOR change, in semver terminology. Sorted.

Implementations

Source

impl PublicApiDiff

pub fn between(old: PublicApi, new: PublicApi) -> Self

Allows you to diff the public API between two arbitrary versions of a library, e.g. different releases. The input parameters old and new is the output of two different invocations of crate::Builder::build.

pub fn is_empty(&self) -> bool

Check whether the diff is empty